#[non_exhaustive]pub struct Trng { /* private fields */ }unstable only.Expand description
True Random Number Generator (TRNG)
The Trng struct represents a true random number generator that combines
the randomness from the hardware RNG and an ADC. This struct provides
methods to generate random numbers and fill buffers with random bytes.
Due to pulling the entropy source from the ADC, it uses the associated
registers, so to use TRNG we need to “occupy” the ADC peripheral.
To generate true random numbers, an instance of TrngSource is required. Once created, you
can create Trng instances at any time, as long as the TrngSource is alive.
Example
use esp_hal::rng::{Trng, TrngSource};
let mut buf = [0u8; 16];
// ADC is not available from now
let trng_source = TrngSource::new(peripherals.RNG, peripherals.ADC1.reborrow());
let trng = Trng::try_new()?;
// Generate true random numbers
trng.read(&mut buf);
let true_random_number = trng.random();
// Downgrade to Rng to allow disabling the TrngSource
let rng = trng.downgrade();
// Drop the true random number source. ADC is available now.
core::mem::drop(trng_source);
let mut adc1_config = AdcConfig::new();
let mut adc1_pin = adc1_config.enable_pin(peripherals.GPIO3, Attenuation::_11dB);
let mut adc1 = Adc::new(peripherals.ADC1, adc1_config);
let pin_value = adc1.read_oneshot(&mut adc1_pin)?;
// Now we can only generate pseudo-random numbers...
rng.read(&mut buf);
let pseudo_random_number = rng.random();
// ... but the ADC is available for use.
let pin_value: u16 = adc1.read_oneshot(&mut adc1_pin)?;Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl Trng
impl Trng
Sourcepub fn try_new() -> Result<Self, TrngError>
pub fn try_new() -> Result<Self, TrngError>
Attempts to create a new True Random Number Generator (TRNG) instance.
This function returns a new Trng instance on success, or an error if the
TrngSource is not active.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn random(&self) -> u32
pub fn random(&self) -> u32
Returns a new, random u32 integer.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.