#[non_exhaustive]pub struct Rng;Expand description
Implementations
Sourceimpl Rng
impl Rng
Sourcepub fn random(&self) -> u32
pub fn random(&self) -> u32
Reads currently available u32 integer from RNG.
Example
use esp_hal::rng::Rng;
let rng = Rng::new();
let random_number = rng.random();Sourcepub fn read(&self, buffer: &mut [u8])
pub fn read(&self, buffer: &mut [u8])
Reads enough bytes from hardware random number generator to fill
buffer.
Example
use esp_hal::rng::Rng;
let rng = Rng::new();
let mut rng_values = [0; 10];
rng.read(&mut rng_values);Sourcepub unsafe fn read_into_raw(&self, ptr: *mut u8, len: usize)
Available on crate feature unstable only.
pub unsafe fn read_into_raw(&self, ptr: *mut u8, len: usize)
unstable only.Reads enough bytes from hardware random number generator to fill
buffer.
If any error is encountered then this function immediately returns. The contents of buf are unspecified in this case.
Safety
ptr must not be null and valid for writes for len bytes.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.